mailr10579 - /branches/bieri_gui/gui_bieri/analyses/auto_rx_base.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on January 29, 2010 - 11:48:
Author: bugman
Date: Fri Jan 29 11:48:51 2010
New Revision: 10579

URL: http://svn.gna.org/viewcvs/relax?rev=10579&view=rev
Log:
Initialised the list_file and relax_times data storage variables to be 
populated with ''.

The length is set to the hardcoded value in self.peak_list_count.


Modified:
    branches/bieri_gui/gui_bieri/analyses/auto_rx_base.py

Modified: branches/bieri_gui/gui_bieri/analyses/auto_rx_base.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/bieri_gui/gui_bieri/analyses/auto_rx_base.py?rev=10579&r1=10578&r2=10579&view=diff
==============================================================================
--- branches/bieri_gui/gui_bieri/analyses/auto_rx_base.py (original)
+++ branches/bieri_gui/gui_bieri/analyses/auto_rx_base.py Fri Jan 29 11:48:51 
2010
@@ -65,8 +65,10 @@
         # Alias the storage container in the relax data store.
         self.data = ds.relax_gui.analyses[hardcoded_index]
 
-        # Hardcoded class variables.
-        self.peak_list_count = 14    # The number of peak list elements.
+        # The number of peak list elements (update the data store to match).
+        self.peak_list_count = 14
+        self.data.file_list = [''] * self.peak_list_count
+        self.data.relax_times = [''] * self.peak_list_count
 
         # The parent GUI element for this class.
         self.parent = wx.Panel(notebook, -1)




Related Messages


Powered by MHonArc, Updated Fri Jan 29 12:00:02 2010